@@ -734,12 +734,17 @@ return(varcov)
     if(is.null(param$mean)) param$mean<-0
     if(is.null(param$nugget)) param$nugget<-0  
     #if(length(param$mean)>1) MM=fixed$mean
+    if(is.null(param$sill)) param$sill<-1  
 }
     else{
     if(is.null(param$mean_1)) param$mean_1<-0
     if(is.null(param$mean_2)) param$mean_2<-0
     if(is.null(param$nugget_1)) param$nugget_1<-0
-    if(is.null(param$nugget_2)) param$nugget_2<-0 }
+    if(is.null(param$nugget_2)) param$nugget_2<-0 
+    if(is.null(param$sill_1)) param$sill_1<-0
+    if(is.null(param$sill_2)) param$sill_2<-0 
+
+}
 
     
 
